@@ -21,8 +21,8 @@
 #ifndef PREVIEWPLUGINSMODEL_H
 #define PREVIEWPLUGINSMODEL_H
 
-#include <QAbstractListModel>
 #include <KService>
+#include <QAbstractListModel>
 
 class QStringList;
 
@@ -32,27 +32,31 @@ class PreviewPluginsModel : public QAbstractListModel
 
     Q_PROPERTY(QStringList checkedPlugins READ checkedPlugins WRITE setCheckedPlugins NOTIFY checkedPluginsChanged)
 
-    public:
-        explicit PreviewPluginsModel(QObject *parent = nullptr);
-        ~PreviewPluginsModel() override;
+public:
+    explicit PreviewPluginsModel(QObject *parent = nullptr);
+    ~PreviewPluginsModel() override;
 
-        QHash<int, QByteArray> roleNames() const override;
-        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
-        bool setData(const QModelIndex &index, const QVariant &value, int role) override;
+    QHash<int, QByteArray> roleNames() const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role) override;
 
-        int rowCount(const QModelIndex &parent = QModelIndex()) const override { Q_UNUSED(parent) return m_plugins.size(); }
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override
+    {
+        Q_UNUSED(parent)
+        return m_plugins.size();
+    }
 
-        QStringList checkedPlugins() const;
-        void setCheckedPlugins(const QStringList &list);
+    QStringList checkedPlugins() const;
+    void setCheckedPlugins(const QStringList &list);
 
-    Q_SIGNALS:
-        void checkedPluginsChanged() const;
+Q_SIGNALS:
+    void checkedPluginsChanged() const;
 
-    private:
-        int indexOfPlugin(const QString &name) const;
+private:
+    int indexOfPlugin(const QString &name) const;
 
-        KService::List m_plugins;
-        QVector<bool> m_checkedRows;
+    KService::List m_plugins;
+    QVector<bool> m_checkedRows;
 };
 
 #endif
