@@ -36,67 +36,67 @@
 #include <KComponentData>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KStandardDirs>
 #include <KProcess>
-#include <QFile>
+#include <KStandardDirs>
 #include <QDebug>
+#include <QFile>
 
 #if defined(USE_SOLARIS)
 #include <KTemporaryFile>
 #include <sys/param.h>
-#include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #endif
 
 // We cannot rely on the $PATH environment variable, because D-Bus activation
 // clears it. So we have to use a reasonable default.
 static const QString exePath = QStringLiteral("/usr/sbin:/usr/bin:/sbin:/bin");
 
-int ClockHelper::ntp( const QStringList& ntpServers, bool ntpEnabled )
+int ClockHelper::ntp(const QStringList &ntpServers, bool ntpEnabled)
 {
     int ret = 0;
 
     // write to the system config file
     QFile config_file(KDE_CONFDIR "/kcmclockrc");
-    if(!config_file.exists()) {
+    if (!config_file.exists()) {
         config_file.open(QIODevice::WriteOnly);
         config_file.close();
         config_file.setPermissions(QFile::ReadOwner | QFile::WriteOwner | QFile::ReadGroup | QFile::ReadOther);
     }
     KConfig _config(config_file.fileName(), KConfig::SimpleConfig);
     KConfigGroup config(&_config, "NTP");
-    config.writeEntry("servers", ntpServers );
-    config.writeEntry("enabled", ntpEnabled );
+    config.writeEntry("servers", ntpServers);
+    config.writeEntry("enabled", ntpEnabled);
 
     QString ntpUtility = QStandardPaths::findExecutable(QStringLiteral("ntpdate"));
     if (ntpUtility.isEmpty()) {
         ntpUtility = QStandardPaths::findExecutable(QStringLiteral("rdate"));
     }
 
-    if ( ntpEnabled && !ntpUtility.isEmpty() ) {
+    if (ntpEnabled && !ntpUtility.isEmpty()) {
         // NTP Time setting
         QString timeServer = ntpServers.first();
-        if( timeServer.indexOf( QRegExp(QStringLiteral(".*\\(.*\\)$")) ) != -1 ) {
-            timeServer.remove( QRegExp(QStringLiteral(".*\\(")));
-            timeServer.remove( QRegExp(QStringLiteral("\\).*")));
+        if (timeServer.indexOf(QRegExp(QStringLiteral(".*\\(.*\\)$"))) != -1) {
+            timeServer.remove(QRegExp(QStringLiteral(".*\\(")));
+            timeServer.remove(QRegExp(QStringLiteral("\\).*")));
             // Would this be better?: s/^.*\(([^)]*)\).*$/\1/
         }
 
         KProcess proc;
         proc << ntpUtility << timeServer;
-        if ( proc.execute() != 0 ) {
+        if (proc.execute() != 0) {
             ret |= NTPError;
         } else {
             toHwclock();
         }
-    } else if( ntpEnabled ) {
+    } else if (ntpEnabled) {
         ret |= NTPError;
     }
 
     return ret;
 }
 
-int ClockHelper::date( const QString& newdate, const QString& olddate )
+int ClockHelper::date(const QString &newdate, const QString &olddate)
 {
     struct timeval tv;
 
@@ -111,18 +111,18 @@ int ClockHelper::date( const QString& newdate, const QString& olddate )
 }
 
 // on non-Solaris systems which do not use /etc/timezone?
-int ClockHelper::tz( const QString& selectedzone )
+int ClockHelper::tz(const QString &selectedzone)
 {
     int ret = 0;
 
-    //only allow letters, numbers hyphen underscore plus and forward slash
-    //allowed pattern taken from time-util.c in systemd
+    // only allow letters, numbers hyphen underscore plus and forward slash
+    // allowed pattern taken from time-util.c in systemd
     if (!QRegExp(QStringLiteral("[a-zA-Z0-9-_+/]*")).exactMatch(selectedzone)) {
         return ret;
     }
 
     QString val;
-#if defined(USE_SOLARIS)	// MARCO
+#if defined(USE_SOLARIS) // MARCO
     KTemporaryFile tf;
     tf.setPrefix("kde-tzone");
     tf.open();
@@ -131,28 +131,21 @@ int ClockHelper::tz( const QString& selectedzone )
     QFile fTimezoneFile(INITFILE);
     bool updatedFile = false;
 
-    if (fTimezoneFile.open(QIODevice::ReadOnly))
-    {
+    if (fTimezoneFile.open(QIODevice::ReadOnly)) {
         bool found = false;
 
         QTextStream is(&fTimezoneFile);
 
-        for (QString line = is.readLine(); !line.isNull();
-             line = is.readLine())
-        {
-            if (line.find("TZ=") == 0)
-            {
+        for (QString line = is.readLine(); !line.isNull(); line = is.readLine()) {
+            if (line.find("TZ=") == 0) {
                 ts << "TZ=" << selectedzone << endl;
                 found = true;
-            }
-            else
-            {
+            } else {
                 ts << line << endl;
             }
         }
 
-        if (!found)
-        {
+        if (!found) {
             ts << "TZ=" << selectedzone << endl;
         }
 
@@ -160,29 +153,22 @@ int ClockHelper::tz( const QString& selectedzone )
         fTimezoneFile.close();
     }
 
-    if (updatedFile)
-    {
+    if (updatedFile) {
         ts.device()->reset();
         fTimezoneFile.remove();
 
-        if (fTimezoneFile.open(QIODevice::WriteOnly | QIODevice::Truncate))
-        {
+        if (fTimezoneFile.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
             QTextStream os(&fTimezoneFile);
 
-            for (QString line = ts->readLine(); !line.isNull();
-                 line = ts->readLine())
-            {
+            for (QString line = ts->readLine(); !line.isNull(); line = ts->readLine()) {
                 os << line << endl;
             }
 
-            fchmod(fTimezoneFile.handle(),
-                   S_IXUSR | S_IRUSR | S_IRGRP | S_IXGRP |
-                   S_IROTH | S_IXOTH);
+            fchmod(fTimezoneFile.handle(), S_IXUSR | S_IRUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
             fTimezoneFile.close();
         }
     }
 
-
     val = selectedzone;
 #else
     QString tz = "/usr/share/zoneinfo/" + selectedzone;
@@ -216,8 +202,8 @@ int ClockHelper::tz( const QString& selectedzone )
 int ClockHelper::tzreset()
 {
 #if !defined(USE_SOLARIS) // Do not update the System!
-    unlink( "/etc/timezone" );
-    unlink( "/etc/localtime" );
+    unlink("/etc/timezone");
+    unlink("/etc/localtime");
 
     setenv("TZ", "", 1);
     tzset();
@@ -240,17 +226,17 @@ ActionReply ClockHelper::save(const QVariantMap &args)
     bool _tz = args.value(QStringLiteral("tz")).toBool();
     bool _tzreset = args.value(QStringLiteral("tzreset")).toBool();
 
-    KComponentData data( "kcmdatetimehelper" );
+    KComponentData data("kcmdatetimehelper");
 
     int ret = 0; // error code
     //  The order here is important
-    if( _ntp )
-        ret |= ntp( args.value(QStringLiteral("ntpServers")).toStringList(), args.value(QStringLiteral("ntpEnabled")).toBool());
-    if( _date )
-        ret |= date( args.value(QStringLiteral("newdate")).toString(), args.value(QStringLiteral("olddate")).toString() );
-    if( _tz )
-        ret |= tz( args.value(QStringLiteral("tzone")).toString() );
-    if( _tzreset )
+    if (_ntp)
+        ret |= ntp(args.value(QStringLiteral("ntpServers")).toStringList(), args.value(QStringLiteral("ntpEnabled")).toBool());
+    if (_date)
+        ret |= date(args.value(QStringLiteral("newdate")).toString(), args.value(QStringLiteral("olddate")).toString());
+    if (_tz)
+        ret |= tz(args.value(QStringLiteral("tzone")).toString());
+    if (_tzreset)
         ret |= tzreset();
 
     if (ret == 0) {
