@@ -19,7 +19,8 @@
 #ifndef XKB_HELPER_H_
 #define XKB_HELPER_H_
 
-template<typename T> class QList;
+template<typename T>
+class QList;
 class LayoutUnit;
 class QStringList;
 class KeyboardConfig;
